cap log c
clear all
set matsize 800
set more off
cd "X:\Course spatial econometrics\Rome2021\" 
* Note this directory is user-specific and should be changed to your own directory

////Spatial panel model estimation by ML using Stata////
*Example using Baltagi and Li (2004) cigarette demand panel data set

* Instructions for students
* First, the routine xsmle should be installed if this has not been done yet.
* type in the command mode
* findit xsmle
* install the latest version

* Next, the routine spmat should be installed if this has not been done yet
* type in the command mode
* findit spmat
* click on "st292" on top of the page
* then click on "(click here to install)"

//row-normalized binary contiguity W matrix
use "W.dta", clear 
spmat dta W s*, normalize(row)

//Read in data set
use "cigarettecf.dta", clear

//Panel 
xtset state year

//Descriptive statistics
//xtsum
//xtdes

// Results of CD-test and exponent alpha, if xtcd2 and xtcse2 are installed
xtcse2 logc

//Notes:
*1) Estimations below include both spatial and time fixed effects
*2) nsim() is optional to set the number of simulations to compute direct,indirect effect
*3) There is also an option to include the lagged dependent variable

//OLS
*non-spatial model with spatial and time fixed effects
tab year, gen(year)
xtreg logc logp logy year*, fe 

//Spatial Durbin model (SDM)
xsmle logc logp logy, wmat(W) model(sdm) fe type(both) nsim(500) effects nsim(500) iter(25)

//Spatial Durbin error model (SDEM)
xsmle logc logp logy wlogp wlogy, emat(W) model(sem) fe type(both) iter(25)

//Dynamic spatial Durbin model (dynamic SDM)
xsmle logc logp logy, wmat(W) model(sdm) dlag(3) fe type(both) effects nsim(500) iter(25)

//Dynamic Spatial model + CF with spatial fixed effects but no time fixed effects
xsmle logc logp logy logct*, wmat(W) model(sdm) dlag(3) durbin(logp logy) fe type(ind) effects nsim(500) iter(25)